Release Notes: GraSPy 0.0.1
===========================

We're happy to announce the release of GraSPy 0.0.1! GraSPy is a Python package for 
understanding the properties of random graphs that arise from modern datasets, such as social networks 
and brain networks.

For more information, please visit our `website <http://graspy.neurodata.io/>`_
and our `tutorials
<https://graspy.neurodata.io/tutorial.html>`_.

Highlights
----------
This release is the result of over two years of work with 238 commits and 35 merges by 4 contributors. 
Highlights include:
- Fast implementation of dimensionailty reduction using different implementation of SVD.
- Single and multiple graph embedding methods.
- Methods for preprocessing graphs for meaningful embeddings.
- Hypothesis testing, specifically semiparametric testing of two graphs.
- Methods for clustering vertices or population of graphs
- Plotting functions for visualization of graphs and high dimensional data.

API Changes
-----------
All classes are based on scikit-learn's API, making the use familiar. 

Deprecations
------------
None.

Contributors to this release
----------------------------

- Jaewon Chung
- Benjamin Pedigo
- Eric Bridgeford
- Bijan Varjavand